#line 2 "libxlu_disk_l.c"
#line 31 "libxlu_disk_l.l"
#include "libxl_osdeps.h" /* must come before any other headers */



#line 8 "libxlu_disk_l.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE xlu__disk_yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via xlu__disk_yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void xlu__disk_yyrestart (FILE *input_file ,yyscan_t yyscanner );
void xlu__disk_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE xlu__disk_yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void xlu__disk_yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void xlu__disk_yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void xlu__disk_yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void xlu__disk_yypop_buffer_state (yyscan_t yyscanner );

static void xlu__disk_yyensure_buffer_stack (yyscan_t yyscanner );
static void xlu__disk_yy_load_buffer_state (yyscan_t yyscanner );
static void xlu__disk_yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER xlu__disk_yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE xlu__disk_yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE xlu__disk_yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE xlu__disk_yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *xlu__disk_yyalloc (yy_size_t ,yyscan_t yyscanner );
void *xlu__disk_yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void xlu__disk_yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer xlu__disk_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        xlu__disk_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            xlu__disk_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        xlu__disk_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            xlu__disk_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define xlu__disk_yywrap(yyscanner) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyg->yytext_ptr -= yyg->yy_more_len; \
	yyleng = (size_t) (yy_cp - yyg->yytext_ptr); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 36
#define YY_END_OF_BUFFER 37
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[575] =
    {   0,
       35,   35,   37,   33,   34,   36, 8193,   33,   34,   36,
    16385, 8193,   33,   36,16385,   33,   34,   36,   34,   36,
       33,   34,   36,   33,   34,   36,   33,   34,   36,   33,
       34,   36,   33,   34,   36,   33,   34,   36,   33,   34,
       36,   33,   34,   36,   33,   34,   36,   33,   34,   36,
       33,   34,   36,   33,   34,   36,   33,   34,   36,   33,
       34,   36,   33,   34,   36,   33,   34,   36,   35,   36,
       36,   33,   33, 8193,   33, 8193,   33,16385, 8193,   33,
     8193,   33,   33, 8224,   33,16416,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   35,
     8193,   33, 8193,   33, 8193, 8224,   33, 8224,   33, 8224,
       23,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33, 8224,   33, 8224,   33, 8224,
       23,   33,   33,   28, 8224,   33,16416,   33,   33,   15,
       33,   33,   33,   33,   33,   33,   33,   33,   33, 8217,
     8224,   33,16409,16416,   33,   33,   31, 8224,   33,16416,
       33, 8216, 8224,   33,16408,16416,   33,   33, 8219, 8224,
       33,16411,16416,   33,   33,   33,   33,   33,   28, 8224,

       33,   28, 8224,   33,   28,   33,   28, 8224,   33,    3,
       33,   15,   33,   33,   33,   33,   33,   30, 8224,   33,
    16416,   33,   33,   33, 8217, 8224,   33, 8217, 8224,   33,
     8217,   33, 8217, 8224,   33,   33,   31, 8224,   33,   31,
     8224,   33,   31,   33,   31, 8224, 8216, 8224,   33, 8216,
     8224,   33, 8216,   33, 8216, 8224,   33, 8219, 8224,   33,
     8219, 8224,   33, 8219,   33, 8219, 8224,   33,   33,   10,
       33,   33,   28, 8224,   33,   28, 8224,   33,   28, 8224,
       28,   33,   28,   33,    3,   33,   33,   33,   33,   33,
       33,   33,   30, 8224,   33,   30, 8224,   33,   30,   33,

       30, 8224,   33,   33,   29, 8224,   33,16416, 8217, 8224,
       33, 8217, 8224,   33, 8217, 8224, 8217,   33, 8217,   33,
       33,   31, 8224,   33,   31, 8224,   33,   31, 8224,   31,
       33,   31, 8216, 8224,   33, 8216, 8224,   33, 8216, 8224,
     8216,   33, 8216,   33, 8219, 8224,   33, 8219, 8224,   33,
     8219, 8224, 8219,   33, 8219,   33,   33,   10,   23,   10,
        7,   33,   33,   33,   33,   33,   33,   33,   13,   33,
       30, 8224,   33,   30, 8224,   33,   30, 8224,   30,   33,
       30,    2,   33,   29, 8224,   33,   29, 8224,   33,   29,
       33,   29, 8224,   16,   33,   33,   11,   33,   22,   10,

       10,   23,    7,   23,    7,   33,    8,   33,   33,   33,
       33,    6,   33,   13,   33,    2,   23,    2,   33,   29,
     8224,   33,   29, 8224,   33,   29, 8224,   29,   33,   29,
       16,   33,   33,   11,   23,   11,   26, 8224,   33,16416,
       22,   23,   22,    7,    7,   23,   33,    8,   23,    8,
       33,   33,   33,   33,    6,   23,    6,    6,   23,    6,
       23,   33,    2,    2,   23,   33,   33,   11,   11,   23,
       26, 8224,   33,   26, 8224,   33,   26,   33,   26, 8224,
       22,   23,   33,    8,    8,   23,   33,   33,   17,   18,
        6,    6,   23,    6,    6,   33,   33,   14,   33,   26,

     8224,   33,   26, 8224,   33,   26, 8224,   26,   33,   26,
       33,   33,   33,   17,   23,   17,   18,   23,   18,    6,
        6,   33,   33,   14,   33,   20,    9,   19,   17,   17,
       23,   18,   18,   23,    6,    5,    6,   33,   21,   20,
       23,   20,    9,   23,    9,   19,   23,   19,    4,    6,
        5,    6,   33,   21,   23,   21,   20,   20,   23,    9,
        9,   23,   19,   19,   23,    4,    6,   12,   33,   21,
       21,   23,   12,   33
    } ;

static yyconst flex_int16_t yy_accept[356] =
    {   0,
        1,    1,    1,    2,    3,    4,    7,   12,   16,   19,
       21,   24,   27,   30,   33,   36,   39,   42,   45,   48,
       51,   54,   57,   60,   63,   66,   69,   71,   72,   73,
       74,   76,   79,   81,   82,   83,   84,   87,   87,   88,
       89,   90,   91,   92,   93,   94,   95,   96,   97,   98,
       99,  100,  101,  102,  103,  104,  105,  106,  107,  108,
      109,  110,  111,  113,  115,  116,  118,  120,  121,  122,
      123,  124,  125,  126,  127,  128,  129,  130,  131,  132,
      133,  134,  135,  136,  137,  138,  139,  140,  141,  142,
      143,  144,  145,  146,  148,  150,  151,  152,  153,  154,

      158,  159,  160,  162,  163,  164,  165,  166,  167,  168,
      169,  170,  175,  176,  177,  181,  182,  187,  188,  189,
      194,  195,  196,  197,  198,  199,  202,  205,  207,  209,
      210,  212,  214,  215,  216,  217,  218,  222,  223,  224,
      225,  228,  231,  233,  235,  236,  237,  240,  243,  245,
      247,  250,  253,  255,  257,  258,  261,  264,  266,  268,
      269,  270,  271,  272,  273,  276,  279,  281,  283,  284,
      285,  287,  288,  289,  290,  291,  292,  293,  296,  299,
      301,  303,  304,  305,  309,  312,  315,  317,  319,  320,
      321,  322,  325,  328,  330,  332,  333,  336,  339,  341,

      343,  344,  345,  348,  351,  353,  355,  356,  357,  358,
      360,  361,  362,  363,  364,  365,  366,  367,  368,  369,
      371,  374,  377,  379,  381,  382,  383,  384,  387,  390,
      392,  394,  396,  397,  398,  399,  400,  401,  403,  405,
      406,  407,  408,  409,  410,  411,  412,  413,  414,  416,
      418,  419,  420,  423,  426,  428,  430,  431,  433,  434,
      436,  437,  441,  443,  444,  445,  447,  448,  450,  451,
      452,  453,  454,  455,  457,  458,  460,  462,  463,  464,
      466,  467,  468,  469,  471,  474,  477,  479,  481,  483,
      484,  485,  487,  488,  489,  490,  491,  492,  494,  495,

      496,  497,  498,  500,  503,  506,  508,  510,  511,  512,
      513,  514,  516,  517,  519,  520,  521,  522,  523,  524,
      526,  527,  528,  529,  530,  532,  533,  535,  536,  538,
      539,  540,  542,  543,  545,  546,  548,  549,  551,  553,
      554,  556,  557,  558,  560,  561,  563,  564,  566,  568,
      570,  571,  573,  575,  575
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    5,    1,    1,    6,    6,    7,
        6,    6,    6,    6,    6,    6,    6,    8,    1,    1,
        9,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   10,   11,   12,   13,

       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   19,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[35] =
    {   0,
        1,    1,    2,    3,    1,    1,    1,    1,    4,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[424] =
    {   0,
        0,    0,  901,  900,  902,  897,   33,   36,  905,  905,
       45,   63,   31,   42,   51,   52,  890,   33,   65,   67,
       69,   70,  889,   71,  888,   75,    0,  905,  893,  905,
       91,   94,    0,    0,  103,  886,  112,    0,   89,   98,
      113,   92,  114,   99,  100,   48,  121,  116,  119,   74,
      124,  129,  123,  135,  132,  133,  137,  134,  138,  139,
      141,    0,  155,    0,    0,  164,    0,    0,  849,  142,
      152,  164,  140,  161,  165,  166,  167,  168,  169,  173,
      174,  178,  176,  180,  184,  208,  189,  183,  192,  195,
      215,  191,  193,  223,    0,    0,  905,  208,  204,  236,

      219,  209,  238,  196,  237,  831,  242,  815,  241,  224,
      243,  261,  244,  259,  277,  266,  286,  250,  288,  298,
      249,  283,  274,  282,  294,  308,    0,  310,    0,  295,
      305,  905,  308,  306,  313,  314,  342,  319,  316,  320,
      331,    0,  349,    0,  342,  344,  356,    0,  358,    0,
      365,    0,  367,    0,  354,  375,    0,  377,    0,  363,
      356,  809,  327,  322,  384,    0,    0,    0,    0,  379,
      905,  382,  384,  386,  390,  372,  392,  403,    0,  410,
        0,  407,  413,  423,  426,    0,    0,    0,    0,  409,
      424,  435,    0,    0,    0,    0,  437,    0,    0,    0,

        0,  433,  444,    0,    0,    0,    0,  391,  440,  781,
      905,  769,  439,  445,  444,  447,  449,  454,  453,  399,
      464,    0,    0,    0,    0,  757,  465,  476,    0,  478,
        0,  479,  476,  753,  462,  490,  749,  905,  745,  905,
      483,  737,  424,  485,  487,  490,  500,  493,  905,  729,
      905,  502,  518,    0,    0,    0,    0,  905,  498,  721,
      905,  527,  713,    0,  705,  905,  495,  697,  905,  365,
      521,  528,  530,  685,  905,  534,  540,  540,  657,  905,
      537,  542,  650,  905,  553,    0,  557,    0,    0,  551,
      641,  905,  558,  557,  633,  614,  613,  905,  547,  555,

      563,  565,  569,  584,    0,    0,    0,    0,  583,  570,
      585,  612,  905,  601,  905,  522,  580,  589,  594,  905,
      600,  585,  563,  520,  905,  514,  905,  586,  486,  597,
      480,  441,  905,  416,  905,  345,  905,  334,  905,  601,
      254,  905,  242,  905,  200,  905,  151,  905,  905,  607,
       86,  905,  905,  905,  620,  624,  627,  631,  635,  639,
      643,  647,  651,  655,  659,  663,  667,  671,  675,  679,
      683,  687,  691,  695,  699,  703,  707,  711,  715,  719,
      723,  727,  731,  735,  739,  743,  747,  751,  755,  759,
      763,  767,  771,  775,  779,  783,  787,  791,  795,  799,

      803,  807,  811,  815,  819,  823,  827,  831,  835,  839,
      843,  847,  851,  855,  859,  863,  867,  871,  875,  879,
      883,  887,  891
    } ;

static yyconst flex_int16_t yy_def[424] =
    {   0,
      354,    1,  355,  355,  354,  356,  357,  357,  354,  354,
      358,  358,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  359,  354,  356,  354,
      360,  357,  361,  361,  362,   12,  356,  363,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,  359,  360,  361,  361,  364,  365,  365,  354,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,  362,   12,   12,   12,   12,
       12,   12,   12,  364,  365,  365,  354,   12,   12,  366,

       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,  367,   86,   86,  368,   12,  369,   12,   12,  370,
       12,   12,   12,   12,   12,  371,  372,  366,  372,   12,
       12,  354,   86,   12,   12,   12,  373,   12,   12,   12,
      374,  375,  367,  375,   86,   86,  376,  377,  368,  377,
      378,  379,  369,  379,   12,  380,  381,  370,  381,   12,
       12,  382,   12,   12,  371,  372,  372,  383,  383,   12,
      354,   86,   86,   86,   12,   12,   12,  384,  385,  373,
      385,   12,   12,  386,  374,  375,  375,  387,  387,   86,
       86,  376,  377,  377,  388,  388,  378,  379,  379,  389,

      389,   12,  380,  381,  381,  390,  390,   12,   12,  391,
      354,  392,   86,   12,   86,   86,   86,   12,   86,   12,
      384,  385,  385,  393,  393,  394,   86,  395,  396,  386,
      396,   86,   86,  397,   12,  398,  391,  354,  399,  354,
       86,  400,   12,   86,   86,   86,  401,   86,  354,  402,
      354,   86,  395,  396,  396,  403,  403,  354,   86,  404,
      354,  405,  406,  406,  399,  354,   86,  407,  354,   12,
       86,   86,   86,  408,  354,  408,  408,   86,  402,  354,
       86,   86,  404,  354,  409,  410,  405,  410,  406,   86,
      407,  354,   12,   86,  411,  412,  408,  354,  408,  408,

       86,   86,   86,  409,  410,  410,  413,  413,   86,   12,
       86,  414,  354,  415,  354,  408,  408,   86,   86,  354,
      416,  417,  418,  414,  354,  415,  354,  408,  408,   86,
      419,  420,  354,  421,  354,  422,  354,  408,  354,   86,
      423,  354,  420,  354,  421,  354,  422,  354,  354,   86,
      423,  354,  354,    0,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,

      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354
    } ;

static yyconst flex_int16_t yy_nxt[940] =
    {   0,
        6,    7,    8,    9,    6,    6,    6,    6,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   17,   17,
       17,   17,   20,   17,   21,   22,   23,   24,   25,   17,
       26,   17,   17,   17,   32,   32,   33,   32,   32,   33,
       36,   34,   36,   42,   34,   29,   29,   29,   30,   35,
       50,   36,   37,   38,   43,   44,   39,   36,   79,   45,
       36,   36,   40,   29,   29,   29,   30,   35,   46,   48,
       37,   38,   41,   47,   36,   49,   36,   53,   36,   36,
       36,   56,   58,   36,   36,   55,   82,   60,   51,  342,
       54,   61,   52,   29,   64,   32,   32,   33,   36,   65,

       70,   36,   34,   29,   29,   29,   30,   36,   36,   36,
       29,   38,   66,   66,   66,   67,   66,   71,   74,   66,
       68,   72,   36,   36,   73,   36,   77,   78,   36,   76,
       36,   53,   36,   36,   75,   85,   80,   83,   36,   86,
       84,   36,   36,   36,   36,   81,   36,   36,   36,   36,
       36,   36,   93,   89,  337,   98,   88,   29,   64,  101,
       90,   36,   91,   65,   92,   87,   29,   95,   89,   99,
       36,  100,   96,   36,   36,   36,   36,   36,   36,  106,
      105,   85,   36,   36,  102,   36,  107,   36,  103,   36,
      109,  112,   36,   36,  104,  108,  115,  110,   36,  117,

       36,   36,   36,  335,   36,   36,  122,  111,   29,   29,
       29,   30,  118,   36,  116,   29,   38,   36,   36,  113,
      114,  119,  120,  123,   36,   29,   95,  121,   36,  134,
      131,   96,  130,   36,  125,  124,  126,  126,   66,  127,
      126,  132,  133,  126,  129,  333,   36,   36,  135,  137,
       36,   36,   36,  140,  139,   35,   35,  352,   36,   36,
       85,  141,  141,   66,  142,  141,  160,  145,  141,  144,
       35,   35,   89,  117,  155,   36,  146,  147,  147,   66,
      148,  147,  162,   36,  147,  150,  151,  151,   66,  152,
      151,   36,   36,  151,  154,  120,  161,   36,  156,  156,

       66,  157,  156,   36,   36,  156,  159,  164,  171,  163,
       29,  166,   29,  168,   36,   36,  167,  170,  169,   35,
       35,  172,   36,   36,  173,   36,  213,  184,   36,   36,
      175,   36,  174,   29,  186,  212,   36,  349,  183,  187,
      177,  176,  178,  178,   66,  179,  178,  182,  348,  178,
      181,   29,  188,   35,   35,   35,   35,  189,   29,  193,
       29,  195,  190,   36,  194,   36,  196,   29,  198,   29,
      200,  191,   36,  199,   36,  201,  219,   29,  204,   29,
      206,   36,  202,  205,  209,  207,   29,  166,   36,  293,
      208,  214,  167,   35,   35,   35,   35,   35,   35,   36,

       36,   36,  249,  218,  220,   29,  222,  216,   36,  217,
      235,  223,   29,  224,  215,  226,   36,  227,  225,  346,
       35,   35,   36,  228,  228,   66,  229,  228,   29,  186,
      228,  231,  232,   36,  187,  233,   35,   29,  193,   29,
      198,  234,   36,  194,  344,  199,   29,  204,  236,   36,
       35,  241,  205,  242,   36,   35,   35,  270,   35,   35,
       35,   35,  247,   36,   35,   35,   29,  222,  244,  262,
      248,   36,  223,  243,  245,  246,   35,  252,   29,  254,
       29,  256,  258,  342,  255,  259,  257,   35,   35,  339,
       35,   35,   69,  264,   35,   35,   35,   35,   35,   35,

      267,   35,   35,  275,   35,   35,   35,   35,  271,   35,
       35,  276,  277,   35,   35,  272,  278,  315,  273,  281,
       29,  254,  290,  313,  282,  275,  255,  285,  285,   66,
      286,  285,   35,   35,  285,  288,  295,  298,  296,   35,
       35,   35,   35,  298,  301,  328,  299,  294,   35,   35,
      275,   35,   35,   35,  303,   29,  305,  300,  275,   29,
      307,  306,   35,   35,  302,  308,  337,   36,   35,   35,
      309,  310,  320,  316,   35,   35,   35,   35,  322,   36,
       35,   35,  317,  275,  319,  311,   29,  305,  335,  275,
      318,  321,  306,  323,   35,   35,   35,   35,  330,  329,

       35,   35,  331,  333,  327,   35,   35,  338,   35,   35,
      353,  340,   35,   35,  350,  325,  275,  315,   35,   35,
       27,   27,   27,   27,   29,   29,   29,   31,   31,   31,
       31,   36,   36,   36,   36,   62,  313,   62,   62,   63,
       63,   63,   63,   65,  269,   65,   65,   35,   35,   35,
       35,   69,   69,  261,   69,   94,   94,   94,   94,   96,
      251,   96,   96,  128,  128,  128,  128,  143,  143,  143,
      143,  149,  149,  149,  149,  153,  153,  153,  153,  158,
      158,  158,  158,  165,  165,  165,  165,  167,  298,  167,
      167,  180,  180,  180,  180,  185,  185,  185,  185,  187,

      292,  187,  187,  192,  192,  192,  192,  194,  240,  194,
      194,  197,  197,  197,  197,  199,  289,  199,  199,  203,
      203,  203,  203,  205,  284,  205,  205,  210,  210,  210,
      210,  169,  280,  169,  169,  221,  221,  221,  221,  223,
      269,  223,  223,  230,  230,  230,  230,  189,  266,  189,
      189,  196,  211,  196,  196,  201,  261,  201,  201,  207,
      251,  207,  207,  237,  237,  237,  237,  239,  239,  239,
      239,  225,  240,  225,  225,  250,  250,  250,  250,  253,
      253,  253,  253,  255,  238,  255,  255,  260,  260,  260,
      260,  263,  263,  263,  263,  265,  265,  265,  265,  268,

      268,  268,  268,  274,  274,  274,  274,  279,  279,  279,
      279,  257,  211,  257,  257,  283,  283,  283,  283,  287,
      287,  287,  287,  264,  138,  264,  264,  291,  291,  291,
      291,  297,  297,  297,  297,  304,  304,  304,  304,  306,
      136,  306,  306,  312,  312,  312,  312,  314,  314,  314,
      314,  308,   97,  308,  308,  324,  324,  324,  324,  326,
      326,  326,  326,  332,  332,  332,  332,  334,  334,  334,
      334,  336,  336,  336,  336,  341,  341,  341,  341,  343,
      343,  343,  343,  345,  345,  345,  345,  347,  347,  347,
      347,  351,  351,  351,  351,   36,   30,   59,   57,   36,

       30,  354,   28,   28,    5,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354
    } ;

static yyconst flex_int16_t yy_chk[940] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    7,    7,    7,    8,    8,    8,
       13,    7,   18,   13,    8,   11,   11,   11,   11,   11,
       18,   14,   11,   11,   13,   14,   11,   46,   46,   14,
       15,   16,   11,   12,   12,   12,   12,   12,   14,   16,
       12,   12,   12,   15,   19,   16,   20,   20,   21,   22,
       24,   22,   24,   50,   26,   21,   50,   26,   19,  351,
       20,   26,   19,   31,   31,   32,   32,   32,   39,   31,

       39,   42,   32,   35,   35,   35,   35,   40,   44,   45,
       35,   35,   37,   37,   37,   37,   37,   39,   42,   37,
       37,   40,   41,   43,   41,   48,   45,   45,   49,   44,
       47,   47,   53,   51,   43,   53,   48,   51,   52,   54,
       52,   55,   56,   58,   54,   49,   57,   59,   60,   73,
       61,   70,   60,   61,  347,   70,   56,   63,   63,   73,
       58,   71,   59,   63,   59,   55,   66,   66,   57,   71,
       74,   72,   66,   72,   75,   76,   77,   78,   79,   78,
       77,   79,   80,   81,   74,   83,   80,   82,   75,   84,
       82,   85,   88,   85,   76,   81,   87,   83,   87,   89,

       92,   89,   93,  345,   90,  104,   92,   84,   86,   86,
       86,   86,   90,   99,   88,   86,   86,   98,  102,   86,
       86,   91,   91,   93,   91,   94,   94,   91,  101,  104,
      102,   94,  101,  110,   99,   98,  100,  100,  100,  100,
      100,  103,  103,  100,  100,  343,  105,  103,  105,  107,
      109,  107,  111,  110,  109,  113,  113,  341,  121,  118,
      111,  112,  112,  112,  112,  112,  121,  113,  112,  112,
      114,  114,  116,  116,  118,  116,  114,  115,  115,  115,
      115,  115,  123,  123,  115,  115,  117,  117,  117,  117,
      117,  124,  122,  117,  117,  119,  122,  119,  120,  120,

      120,  120,  120,  125,  130,  120,  120,  125,  131,  124,
      126,  126,  128,  128,  131,  134,  126,  130,  128,  133,
      133,  133,  135,  136,  133,  139,  164,  140,  138,  140,
      134,  164,  133,  141,  141,  163,  163,  338,  139,  141,
      136,  135,  137,  137,  137,  137,  137,  138,  336,  137,
      137,  143,  143,  145,  145,  146,  146,  143,  147,  147,
      149,  149,  145,  155,  147,  161,  149,  151,  151,  153,
      153,  146,  160,  151,  270,  153,  176,  156,  156,  158,
      158,  176,  155,  156,  161,  158,  165,  165,  170,  270,
      160,  170,  165,  172,  172,  173,  173,  174,  174,  175,

      208,  177,  220,  175,  177,  178,  178,  173,  220,  174,
      208,  178,  180,  180,  172,  182,  182,  183,  180,  334,
      190,  190,  183,  184,  184,  184,  184,  184,  185,  185,
      184,  184,  190,  243,  185,  191,  191,  192,  192,  197,
      197,  202,  202,  192,  332,  197,  203,  203,  209,  209,
      213,  213,  203,  214,  214,  215,  215,  243,  216,  216,
      217,  217,  218,  218,  219,  219,  221,  221,  215,  235,
      219,  235,  221,  214,  216,  217,  227,  227,  228,  228,
      230,  230,  232,  331,  228,  233,  230,  233,  233,  329,
      232,  232,  236,  236,  241,  241,  244,  244,  245,  245,

      241,  246,  246,  247,  248,  248,  267,  267,  244,  259,
      259,  247,  247,  252,  252,  245,  248,  326,  246,  252,
      253,  253,  267,  324,  259,  316,  253,  262,  262,  262,
      262,  262,  271,  271,  262,  262,  272,  276,  273,  272,
      272,  273,  273,  277,  278,  316,  276,  271,  281,  281,
      299,  278,  278,  282,  282,  285,  285,  277,  300,  287,
      287,  285,  290,  290,  281,  287,  323,  293,  294,  294,
      290,  293,  303,  299,  301,  301,  302,  302,  310,  310,
      303,  303,  300,  317,  302,  294,  304,  304,  322,  328,
      301,  309,  304,  311,  309,  309,  311,  311,  318,  317,

      318,  318,  319,  321,  314,  319,  319,  328,  330,  330,
      350,  330,  340,  340,  340,  312,  297,  296,  350,  350,
      355,  355,  355,  355,  356,  356,  356,  357,  357,  357,
      357,  358,  358,  358,  358,  359,  295,  359,  359,  360,
      360,  360,  360,  361,  291,  361,  361,  362,  362,  362,
      362,  363,  363,  283,  363,  364,  364,  364,  364,  365,
      279,  365,  365,  366,  366,  366,  366,  367,  367,  367,
      367,  368,  368,  368,  368,  369,  369,  369,  369,  370,
      370,  370,  370,  371,  371,  371,  371,  372,  274,  372,
      372,  373,  373,  373,  373,  374,  374,  374,  374,  375,

      268,  375,  375,  376,  376,  376,  376,  377,  265,  377,
      377,  378,  378,  378,  378,  379,  263,  379,  379,  380,
      380,  380,  380,  381,  260,  381,  381,  382,  382,  382,
      382,  383,  250,  383,  383,  384,  384,  384,  384,  385,
      242,  385,  385,  386,  386,  386,  386,  387,  239,  387,
      387,  388,  237,  388,  388,  389,  234,  389,  389,  390,
      226,  390,  390,  391,  391,  391,  391,  392,  392,  392,
      392,  393,  212,  393,  393,  394,  394,  394,  394,  395,
      395,  395,  395,  396,  210,  396,  396,  397,  397,  397,
      397,  398,  398,  398,  398,  399,  399,  399,  399,  400,

      400,  400,  400,  401,  401,  401,  401,  402,  402,  402,
      402,  403,  162,  403,  403,  404,  404,  404,  404,  405,
      405,  405,  405,  406,  108,  406,  406,  407,  407,  407,
      407,  408,  408,  408,  408,  409,  409,  409,  409,  410,
      106,  410,  410,  411,  411,  411,  411,  412,  412,  412,
      412,  413,   69,  413,  413,  414,  414,  414,  414,  415,
      415,  415,  415,  416,  416,  416,  416,  417,  417,  417,
      417,  418,  418,  418,  418,  419,  419,  419,  419,  420,
      420,  420,  420,  421,  421,  421,  421,  422,  422,  422,
      422,  423,  423,  423,  423,   36,   29,   25,   23,   17,

        6,    5,    4,    3,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() (yyg->yy_more_flag = 1)
#define YY_MORE_ADJ yyg->yy_more_len
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "libxlu_disk_l.l"
/* -*- fundamental -*- */
/*
 * libxlu_disk_l.l - parser for disk specification strings
 *
 * Copyright (C) 2011      Citrix Ltd.
 * Author Ian Jackson <ian.jackson@eu.citrix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; version 2.1 only. with the special
 * exception on linking described in file LICENSE.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 */
/*
 * Parsing the old xm/xend/xl-4.1 disk specs is a tricky problem,
 * because the target string might in theory contain "," which is the
 * delimiter we use for stripping off things on the RHS, and ":",
 * which is the delimiter we use for stripping off things on the LHS.
 *
 * In this parser we do not support such target strings in the old
 * syntax; if the target string has to contain "," or ":" the new
 * syntax's "target=" should be used.
 */

#line 35 "libxlu_disk_l.l"
#include "libxlu_disk_i.h"

#define YY_NO_INPUT

/* Some versions of flex have a bug (Fedora bugzilla 612465) which causes
 * it to fail to declare these functions, which it defines.  So declare
 * them ourselves.  Hopefully we won't have to simultaneously support
 * a flex version which declares these differently somehow. */
int xlu__disk_yyget_column(yyscan_t yyscanner);
void xlu__disk_yyset_column(int  column_no, yyscan_t yyscanner);


/*----- useful macros and functions used in actions -----
 * we use macros in the actual rules to keep the actions short
 * and particularly to avoid repeating boilerplate values such as
 * DPC->disk, yytext, etc. */

/* Sets an enum, checking it hasn't already been set to a different value  */
#define DSET(dpc,member,enumname,str,valname) do{			\
	if (dpc->disk->member != LIBXL_DISK_##enumname##_UNKNOWN &&	\
	    dpc->disk->member != LIBXL_DISK_##enumname##_##valname) {	\
	    xlu__disk_err(dpc, str, TOSTRING(member) " respecified");	\
	} else {							\
	    dpc->disk->member = LIBXL_DISK_##enumname##_##valname;	\
	}								\
    }while(0)

/* For actions whose patterns contain '=', finds the start of the value */
#define FROMEQUALS (strchr(yytext,'=')+1)

/* Chops the delimiter off, modifying yytext and yyleng. */
#define STRIP(delim) do{                                                \
	if (yyleng>0 && yytext[yyleng-1]==(delim))                      \
	    yytext[--yyleng] = 0;                                       \
    }while(0)

/* Sets a string value, checking it hasn't been set already. */
#define SAVESTRING(what,loc,val) do{					\
	savestring(DPC, what " respecified", &DPC->disk->loc, (val));	\
    }while(0)
static void savestring(DiskParseContext *dpc, const char *what_respecified,
		       char **update, const char *value) {
    if (*update) {
        if (**update) { xlu__disk_err(dpc,value,what_respecified); return; }
        free(*update); /* do not complain about overwriting empty strings */
    }
    *update = strdup(value);
}

#define DPC dpc /* our convention in lexer helper functions */

/* Sets ->readwrite from the string.  This ought to be an enum, perhaps. */
static void setaccess(DiskParseContext *dpc, const char *str) {
    if (!strcmp(str, "r") || !strcmp(str, "ro")) {
        dpc->disk->readwrite = 0;
    } else if (!strcmp(str, "rw") || !strcmp(str, "w") || !strcmp(str,"")) {
	dpc->disk->readwrite = 1;
    } else {
	xlu__disk_err(dpc,str,"unknown value for access");
    }
}

/* Sets ->format from the string.  IDL should provide something for this. */
static void setformat(DiskParseContext *dpc, const char *str) {
    if      (!strcmp(str,""))       DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"raw"))    DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"qcow"))   DSET(dpc,format,FORMAT,str,QCOW);
    else if (!strcmp(str,"qcow2"))  DSET(dpc,format,FORMAT,str,QCOW2);
    else if (!strcmp(str,"vhd"))    DSET(dpc,format,FORMAT,str,VHD);
    else if (!strcmp(str,"empty"))  DSET(dpc,format,FORMAT,str,EMPTY);
    else if (!strcmp(str,"qed"))    DSET(dpc,format,FORMAT,str,QED);
    else xlu__disk_err(dpc,str,"unknown value for format");
}

/* Sets ->backend from the string.  IDL should provide something for this. */
static void setbackendtype(DiskParseContext *dpc, const char *str) {
    if (     !strcmp(str,"phy"))   DSET(dpc,backend,BACKEND,str,PHY);
    else if (!strcmp(str,"tap"))   DSET(dpc,backend,BACKEND,str,TAP);
    else if (!strcmp(str,"qdisk")) DSET(dpc,backend,BACKEND,str,QDISK);
    else xlu__disk_err(dpc,str,"unknown value for backendtype");
}

/* Sets ->colo-port from the string.  COLO need this. */
static void setcoloport(DiskParseContext *dpc, const char *str) {
    int port = atoi(str);
    if (port) {
       dpc->disk->colo_port = port;
    } else {
	xlu__disk_err(dpc,str,"unknown value for colo_port");
    }
}

#define DEPRECATE(usewhatinstead) /* not currently reported */

/* Handles a vdev positional parameter which includes a devtype. */
static int vdev_and_devtype(DiskParseContext *dpc, char *str) {
    /* returns 1 if it was <vdev>:<devtype>, 0 (doing nothing) otherwise */
    char *colon = strrchr(str, ':');
    if (!colon)
        return 0;

    DEPRECATE("use `devtype=...'");
    *colon++ = 0;
    SAVESTRING("vdev", vdev, str);

    if (!strcmp(colon,"cdrom")) {
        DPC->disk->is_cdrom = 1;
    } else if (!strcmp(colon,"disk")) {
        DPC->disk->is_cdrom = 0;
    } else {
        xlu__disk_err(DPC,colon,"unknown deprecated type");
    }
    return 1;
}

#undef DPC /* needs to be defined differently the actual lexer */
#define DPC ((DiskParseContext*)yyextra)


#line 1006 "libxlu_disk_l.c"

#define INITIAL 0
#define LEXERR 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int xlu__disk_yylex_init (yyscan_t* scanner);

int xlu__disk_yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int xlu__disk_yylex_destroy (yyscan_t yyscanner );

int xlu__disk_yyget_debug (yyscan_t yyscanner );

void xlu__disk_yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE xlu__disk_yyget_extra (yyscan_t yyscanner );

void xlu__disk_yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *xlu__disk_yyget_in (yyscan_t yyscanner );

void xlu__disk_yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *xlu__disk_yyget_out (yyscan_t yyscanner );

void xlu__disk_yyset_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t xlu__disk_yyget_leng (yyscan_t yyscanner );

char *xlu__disk_yyget_text (yyscan_t yyscanner );

int xlu__disk_yyget_lineno (yyscan_t yyscanner );

void xlu__disk_yyset_lineno (int line_number ,yyscan_t yyscanner );

int xlu__disk_yyget_column  (yyscan_t yyscanner );

void xlu__disk_yyset_column (int column_no ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int xlu__disk_yywrap (yyscan_t yyscanner );
#else
extern int xlu__disk_yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int xlu__disk_yylex (yyscan_t yyscanner);

#define YY_DECL int xlu__disk_yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)xlu__disk_yyalloc(YY_STATE_BUF_SIZE  ,yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			xlu__disk_yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				xlu__disk_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		xlu__disk_yy_load_buffer_state(yyscanner );
		}

	{
#line 166 "libxlu_disk_l.l"


 /*----- the scanner rules which do the parsing -----*/

#line 1284 "libxlu_disk_l.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yyg->yy_more_len = 0;
		if ( yyg->yy_more_flag )
			{
			yyg->yy_more_len = yyg->yy_c_buf_p - yyg->yytext_ptr;
			yyg->yy_more_flag = 0;
			}
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 355 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 354 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 170 "libxlu_disk_l.l"
{ /* ignore whitespace before parameters */ }
	YY_BREAK
/* ordinary parameters setting enums or strings */
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 174 "libxlu_disk_l.l"
{ STRIP(','); setformat(DPC, FROMEQUALS); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 176 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 177 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 178 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 0; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 179 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown value for type"); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 181 "libxlu_disk_l.l"
{ STRIP(','); setaccess(DPC, FROMEQUALS); }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 182 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("backend", backend_domname, FROMEQUALS); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 183 "libxlu_disk_l.l"
{ STRIP(','); setbackendtype(DPC,FROMEQUALS); }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 185 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("vdev", vdev, FROMEQUALS); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 186 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("script", script, FROMEQUALS); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 187 "libxlu_disk_l.l"
{ DPC->disk->direct_io_safe = 1; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 188 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, true); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 189 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, false); }
	YY_BREAK
/* Note that the COLO configuration settings should be considered unstable.
  * They may change incompatibly in future versions of Xen. */
case 15:
YY_RULE_SETUP
#line 192 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, true); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 193 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, false); }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 194 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-host", colo_host, FROMEQUALS); }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 195 "libxlu_disk_l.l"
{ STRIP(','); setcoloport(DPC, FROMEQUALS); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 196 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-export", colo_export, FROMEQUALS); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 197 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("active-disk", active_disk, FROMEQUALS); }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 198 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("hidden-disk", hidden_disk, FROMEQUALS); }
	YY_BREAK
/* the target magic parameter, eats the rest of the string */
case 22:
YY_RULE_SETUP
#line 202 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("target", pdev_path, FROMEQUALS); }
	YY_BREAK
/* unknown parameters */
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 206 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown parameter"); }
	YY_BREAK
/* deprecated prefixes */
/* the "/.*" in these patterns ensures that they count as if they
   * matched the whole string, so these patterns take precedence */
case 24:
YY_RULE_SETUP
#line 213 "libxlu_disk_l.l"
{
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `[format=]...,'");
                    setformat(DPC, yytext);
                 }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 219 "libxlu_disk_l.l"
{
                    char *newscript;
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `script=...'");
                    if (asprintf(&newscript, "block-%s", yytext) < 0) {
                            xlu__disk_err(DPC,yytext,"unable to format script");
                            return 0;
                    }
                    savestring(DPC, "script respecified",
                               &DPC->disk->script, newscript);
                    free(newscript);
                }
	YY_BREAK
case 26:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 232 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 233 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 28:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 234 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 29:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 235 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 30:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 236 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 31:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 237 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 239 "libxlu_disk_l.l"
{
		  xlu__disk_err(DPC,yytext,"unknown deprecated disk prefix");
		  return 0;
		}
	YY_BREAK
/* positional parameters */
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 246 "libxlu_disk_l.l"
{
    STRIP(',');

    if (DPC->err) {
        /* previous errors may just lead to subsequent ones */
    } else if (!DPC->disk->pdev_path) {
        SAVESTRING("target", pdev_path, yytext);
    } else if (!DPC->had_depr_prefix &&
               DPC->disk->format == LIBXL_DISK_FORMAT_UNKNOWN) {
        if (!*DPC->disk->pdev_path && vdev_and_devtype(DPC,yytext)) {
            DPC->disk->format = LIBXL_DISK_FORMAT_EMPTY;
        } else {
            setformat(DPC,yytext);
        }
    } else if (!DPC->disk->vdev) {
        if (!vdev_and_devtype(DPC,yytext))
            SAVESTRING("vdev", vdev, yytext);
    } else if (!DPC->access_set) {
        DPC->access_set = 1;
        setaccess(DPC,yytext);
    } else {
        xlu__disk_err(DPC,yytext,"too many positional parameters");
        return 0; /* don't print any more errors */
    }
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 272 "libxlu_disk_l.l"
{
    BEGIN(LEXERR);
    yymore();
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 276 "libxlu_disk_l.l"
{
    xlu__disk_err(DPC,yytext,"bad disk syntax"); return 0;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 279 "libxlu_disk_l.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1637 "libxlu_disk_l.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(LEXERR):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * xlu__disk_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( xlu__disk_yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of xlu__disk_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			xlu__disk_yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) xlu__disk_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 355 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 355 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 354);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					xlu__disk_yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( xlu__disk_yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void xlu__disk_yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        xlu__disk_yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            xlu__disk_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	xlu__disk_yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	xlu__disk_yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void xlu__disk_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		xlu__disk_yypop_buffer_state();
	 *		xlu__disk_yypush_buffer_state(new_buffer);
     */
	xlu__disk_yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	xlu__disk_yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (xlu__disk_yywrap()) processing, but the only time this flag
	 * is looked at is after xlu__disk_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void xlu__disk_yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE xlu__disk_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) xlu__disk_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) xlu__disk_yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	xlu__disk_yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with xlu__disk_yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void xlu__disk_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		xlu__disk_yyfree((void *) b->yy_ch_buf ,yyscanner );

	xlu__disk_yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a xlu__disk_yyrestart() or at EOF.
 */
    static void xlu__disk_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	xlu__disk_yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then xlu__disk_yy_init_buffer was _probably_
     * called from xlu__disk_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void xlu__disk_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		xlu__disk_yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void xlu__disk_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	xlu__disk_yyensure_buffer_stack(yyscanner);

	/* This block is copied from xlu__disk_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from xlu__disk_yy_switch_to_buffer. */
	xlu__disk_yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void xlu__disk_yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	xlu__disk_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		xlu__disk_yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void xlu__disk_yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)xlu__disk_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)xlu__disk_yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE xlu__disk_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) xlu__disk_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	xlu__disk_yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to xlu__disk_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       xlu__disk_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE xlu__disk_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return xlu__disk_yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to xlu__disk_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE xlu__disk_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) xlu__disk_yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in xlu__disk_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = xlu__disk_yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in xlu__disk_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE xlu__disk_yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int xlu__disk_yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int xlu__disk_yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *xlu__disk_yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *xlu__disk_yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t xlu__disk_yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *xlu__disk_yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void xlu__disk_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void xlu__disk_yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "xlu__disk_yyset_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void xlu__disk_yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "xlu__disk_yyset_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see xlu__disk_yy_switch_to_buffer
 */
void xlu__disk_yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void xlu__disk_yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int xlu__disk_yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void xlu__disk_yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* xlu__disk_yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int xlu__disk_yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) xlu__disk_yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* xlu__disk_yylex_init_extra has the same functionality as xlu__disk_yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to xlu__disk_yyalloc in
 * the yyextra field.
 */

int xlu__disk_yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    xlu__disk_yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) xlu__disk_yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    xlu__disk_yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from xlu__disk_yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * xlu__disk_yylex_init()
     */
    return 0;
}

/* xlu__disk_yylex_destroy is for both reentrant and non-reentrant scanners. */
int xlu__disk_yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		xlu__disk_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		xlu__disk_yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	xlu__disk_yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        xlu__disk_yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    xlu__disk_yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * xlu__disk_yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    xlu__disk_yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *xlu__disk_yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *xlu__disk_yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void xlu__disk_yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see xlu__disk_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 278 "libxlu_disk_l.l"
